==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/uk-UA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Підтвердження видалення основних активів',
    'bulk_restore'      => 'Підтвердити масове відновлення активів', 
  'bulk_delete_help'	=> 'Перегляньте активи для масового видалення нижче. Після видалення, ці активи можна відновити, але вони більше не будуть пов\'язані з будь-яким користувачам, на яких вони в даний час прикріплені.',
  'bulk_restore_help'	=> 'Перегляньте активи для відновлення пакета нижче. Після відновлення цих активів не будуть пов\'язані з будь-яким користувачам, на яких вони були присвоєні раніше.',
  'bulk_delete_warn'	=> 'Ви збираєтесь видалити :asset_count активів.',
  'bulk_restore_warn'	=> 'Ви збираєтеся відновити :asset_count активів.',
    'bulk_update'		=> 'Масове оновлення активів',
    'bulk_update_help'	=> 'Ця форма дозволяє вам оновити кілька активів за один раз. Заповніть тільки ті поля, які необхідно змінити. Будь-які вільні поля порожніми, залишаться без змін. ',
    'bulk_update_warn'	=> 'Ви збираєтеся редагувати властивості одного активу. | Ви збираєтеся редагувати властивості :asset_count активів.',
    'bulk_update_with_custom_field' => 'Зверніть увагу на медіафайли :asset_model_count різних типів моделей.',
    'bulk_update_model_prefix' => 'Для моделей', 
    'bulk_update_custom_field_unique' => 'Це унікальне поле і його не можна відредагувати.',
    'checkedout_to'		=> 'Видано',
    'checkout_date'		=> 'Дата видачі',
    'checkin_date'		=> 'Дата повернення',
    'checkout_to'		=> 'Видати',
    'cost'				=> 'Вартість покупки',
    'create'			=> 'Створити актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'Амортизація',
    'depreciates_on'	=> 'Дешевше',
    'default_location'	=> 'Місцезнаходження за замовчуванням',
    'default_location_phone' => 'Телефон за замовчуванням',
    'eol_date'			=> 'Дата EOL',
    'eol_rate'			=> 'Оцінка EOL',
    'expected_checkin'  => 'Очікувана дата повернення',
    'expires'			=> 'Термін закінчується',
    'fully_depreciated'	=> 'Повністю застарілий',
    'help_checkout'		=> 'Якщо ви хочете негайно призначити цей актив, виберіть "Готовий до розгортання" зі списку статусів вище. ',
    'mac_address'		=> 'MAC-адреса',
    'manufacturer'		=> 'Виробник',
    'model'				=> 'Модель',
    'months'			=> 'міс.',
    'name'				=> 'Назва активу',
    'notes'				=> 'Нотатки',
    'order'				=> 'Номер замовлення',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Користувачі можуть запитувати цей медіафайл',
    'select_statustype'	=> 'Виберіть тип статусу',
    'serial'			=> 'Серійник',
    'status'			=> 'Статус',
    'tag'				=> 'Тег активу',
    'update'			=> 'Оновити актив',
    'warranty'			=> 'Гарантія',
        'warranty_expires'		=> 'Гарантійний термін дії',
    'years'				=> 'р.',
    'asset_location' => 'Оновити розташування активу',
    'asset_location_update_default_current' => 'Оновити розташування за замовчуванням і фактичне розташування',
    'asset_location_update_default' => 'Оновити тільки типове розташування',
    'asset_location_update_actual' => 'Оновити тільки фактичне місцезнаходження',
    'asset_not_deployable' => 'Стан активу не є розгортаним. Цей актив не може бути відмічений.',
    'asset_deployable' => 'Цей статус розміщено на ньому. Цей медіафайл може бути перевірений.',
    'processing_spinner' => 'Обробка... (Це може зайняти деякий час для великих файлів)',
    'optional_infos'  => 'Додаткова інформація',
    'order_details'   => 'Пов\'язані відомості про замовлення'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/uk-UA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Підтвердження видалення основних активів',
    'bulk_restore'      => 'Підтвердити масове відновлення активів', 
  'bulk_delete_help'	=> 'Перегляньте активи для масового видалення нижче. Після видалення, ці активи можна відновити, але вони більше не будуть пов\'язані з будь-яким користувачам, на яких вони в даний час прикріплені.',
  'bulk_restore_help'	=> 'Перегляньте активи для відновлення пакета нижче. Після відновлення цих активів не будуть пов\'язані з будь-яким користувачам, на яких вони були присвоєні раніше.',
  'bulk_delete_warn'	=> 'Ви збираєтесь видалити :asset_count активів.',
  'bulk_restore_warn'	=> 'Ви збираєтеся відновити :asset_count активів.',
    'bulk_update'		=> 'Масове оновлення активів',
    'bulk_update_help'	=> 'Ця форма дозволяє вам оновити кілька активів за один раз. Заповніть тільки ті поля, які необхідно змінити. Будь-які вільні поля порожніми, залишаться без змін. ',
    'bulk_update_warn'	=> 'Ви збираєтеся редагувати властивості одного активу. | Ви збираєтеся редагувати властивості :asset_count активів.',
    'bulk_update_with_custom_field' => 'Зверніть увагу на медіафайли :asset_model_count різних типів моделей.',
    'bulk_update_model_prefix' => 'Для моделей', 
    'bulk_update_custom_field_unique' => 'Це унікальне поле і його не можна відредагувати.',
    'checkedout_to'		=> 'Видано',
    'checkout_date'		=> 'Дата видачі',
    'checkin_date'		=> 'Дата повернення',
    'checkout_to'		=> 'Видати',
    'cost'				=> 'Вартість покупки',
    'create'			=> 'Створити актив',
    'date'				=> 'Дата покупки',
    'depreciation'	    => 'Амортизація',
    'depreciates_on'	=> 'Дешевше',
    'default_location'	=> 'Місцезнаходження за замовчуванням',
    'default_location_phone' => 'Телефон за замовчуванням',
    'eol_date'			=> 'Дата EOL',
    'eol_rate'			=> 'Оцінка EOL',
    'expected_checkin'  => 'Очікувана дата повернення',
    'expires'			=> 'Термін закінчується',
    'fully_depreciated'	=> 'Повністю застарілий',
    'help_checkout'		=> 'Якщо ви хочете негайно призначити цей актив, виберіть "Готовий до розгортання" зі списку статусів вище. ',
    'mac_address'		=> 'MAC-адреса',
    'manufacturer'		=> 'Виробник',
    'model'				=> 'Модель',
    'months'			=> 'міс.',
    'name'				=> 'Назва активу',
    'notes'				=> 'Нотатки',
    'order'				=> 'Номер замовлення',
    'qr'				=> 'QR-код',
    'requestable'		=> 'Користувачі можуть запитувати цей медіафайл',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Виберіть тип статусу',
    'serial'			=> 'Серійник',
    'status'			=> 'Статус',
    'tag'				=> 'Тег активу',
    'update'			=> 'Оновити актив',
    'warranty'			=> 'Гарантія',
        'warranty_expires'		=> 'Гарантійний термін дії',
    'years'				=> 'р.',
    'asset_location' => 'Оновити розташування активу',
    'asset_location_update_default_current' => 'Оновити розташування за замовчуванням і фактичне розташування',
    'asset_location_update_default' => 'Оновити тільки типове розташування',
    'asset_location_update_actual' => 'Оновити тільки фактичне місцезнаходження',
    'asset_not_deployable' => 'Стан активу не є розгортаним. Цей актив не може бути відмічений.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Цей статус розміщено на ньому. Цей медіафайл може бути перевірений.',
    'processing_spinner' => 'Обробка... (Це може зайняти деякий час для великих файлів)',
    'optional_infos'  => 'Додаткова інформація',
    'order_details'   => 'Пов\'язані відомості про замовлення'
];
